@@ -5,7 +5,7 @@ use Test::Needs { perl => 5.020 };
 
 use lib 't/lib';
 use TestHelper qw( doc );
-use Test::More import => [ 'done_testing', 'is' ];
+use Test::More import => [qw( done_testing is )];
 
 my $expected = <<'EOF';
 use strict;
